<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="37"/>
        <location filename="../asciifile/asciifile.cpp" line="43"/>
        <source>Read ascii points</source>
        <translation>Точки в форматі ASCII</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Імпорт shape-файлу ESRI</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Вирівняти</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>Перша базова точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>Перша цільова точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>Друга базова точка:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>Друга цільова точка:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Перелік елементів</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Порожній об’єкт</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="73"/>
        <source>Layer</source>
        <translation>Шар</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="75"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="76"/>
        <source>Line type</source>
        <translation>Тип лінії</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Line thickness</source>
        <translation>Товщина лінії</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="78"/>
        <source>ID</source>
        <translation>Ідент. </translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="84"/>
        <source>POINT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="85"/>
        <location filename="../list/list.cpp" line="195"/>
        <source>in point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="90"/>
        <source>LINE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="95"/>
        <source>from point</source>
        <translation>від точки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="98"/>
        <source>to point</source>
        <translation>до точки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="103"/>
        <location filename="../list/list.cpp" line="127"/>
        <source>length</source>
        <translation>довжина</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="108"/>
        <source>Angle in XY plane</source>
        <translation>Кут в площині XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="109"/>
        <source>Inc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="114"/>
        <source>ARC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="115"/>
        <location filename="../list/list.cpp" line="131"/>
        <location filename="../list/list.cpp" line="141"/>
        <source>center point</source>
        <translation>центральна точка</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="121"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="199"/>
        <source>radius</source>
        <translation>радіус</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="122"/>
        <source>initial angle</source>
        <translation>початковий кут</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="123"/>
        <source>final angle</source>
        <translation>кінцевий кут</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="130"/>
        <source>CIRCLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="136"/>
        <source>circumference</source>
        <translation>периметр</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="137"/>
        <source>area</source>
        <translation>площа</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>ELLIPSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>major axis</source>
        <translation>головні осі</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="162"/>
        <source>CONSTRUCTIONLINE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="165"/>
        <source>OVERLAYBOX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="168"/>
        <source>SOLID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>MTEXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="175"/>
        <source>TEXT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="178"/>
        <source>INSERT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="181"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>Insertion point</source>
        <translation>Точка вставки</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>POLYLINE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="188"/>
        <source>Closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>Yes</source>
        <translation>Так</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Vertices</source>
        <translation>Вершини</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">кривизна</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="204"/>
        <source>IMAGE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="207"/>
        <source>SPLINE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>HATCH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="216"/>
        <source>DIMLEADER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="219"/>
        <source>DIMALIGNED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="222"/>
        <source>DIMLINEAR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="225"/>
        <source>DIMRADIAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="228"/>
        <source>DIMDIAMETRIC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="231"/>
        <source>DIMANGULAR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="234"/>
        <source>UNKNOWN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Entity

</source>
        <translation type="obsolete">Пустий об’єкт

</translation>
    </message>
    <message>
        <source>Layer: </source>
        <translation type="obsolete">Шар: </translation>
    </message>
    <message>
        <source>
 Color: </source>
        <translation type="obsolete">
 Колір: </translation>
    </message>
    <message>
        <source> Line type: </source>
        <translation type="obsolete"> Тип лінії: </translation>
    </message>
    <message>
        <source>
 Line thickness: </source>
        <translation type="obsolete">
 Товщина лінії: </translation>
    </message>
    <message>
        <source>ARC: </source>
        <translation type="obsolete">ДУГА: </translation>
    </message>
    <message>
        <source>CIRCLE: </source>
        <translation type="obsolete">КОЛО: </translation>
    </message>
    <message>
        <source>ELLIPSE: </source>
        <translation type="obsolete">ЕЛІПС: </translation>
    </message>
    <message>
        <source>TEXT: </source>
        <translation type="obsolete">ТЕКСТ: </translation>
    </message>
    <message>
        <source>IMAGE: </source>
        <translation type="obsolete">ЗОБРАЖЕННЯ: </translation>
    </message>
    <message>
        <source>SPLINE: </source>
        <translation type="obsolete">СПЛАЙН: </translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Однакові властивості</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>Виберіть вихідний об’єкт</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>Виберіть об’єкти для зміни</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Приклад додатку</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="38"/>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="44"/>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>Read ascii points</source>
        <translation>Точки в форматі ASCII</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="241"/>
        <source>File...</source>
        <translation>Файл…</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="248"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space Separator</source>
        <translation>Поділ пробілами</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Tab Separator</source>
        <translation>Поділ табуляцією</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Comma Separator</source>
        <translation>Поділ комою</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space in Columns</source>
        <translation>Пробіли в стовпцях</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb для Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="252"/>
        <source>Connect points</source>
        <translation>З’єднати точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>2D Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>Draw 2D Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>3D Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>Draw 3D Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Point Number</source>
        <translation>Номер точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Draw point number</source>
        <translation>Нумерувати точки</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Point Elevation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Draw point elevation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Point Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Draw point code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="278"/>
        <source>Accept</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="283"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="313"/>
        <source>Select file</source>
        <translation>Виберіть файл</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point 2D layer is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="323"/>
        <source>Point 3D layer is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point elevation layer is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point elevation height is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="328"/>
        <source>Point elevation separation is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point number layer is empty</source>
        <translation>Шар нумерації точок порожній</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point number height is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="333"/>
        <source>Point number separation is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="336"/>
        <source>Point code layer is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="337"/>
        <source>Point code height is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="338"/>
        <source>Point code separation is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="366"/>
        <source>The file %1 not exist</source>
        <translation>Не існує файл %1</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="371"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Неможливо відкрити файл %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Файл…</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Тип файлу:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Шар</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Імпорт shape-файлу ESRI</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Невідомо</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Поточний</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>З даних: </translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Тип лінії</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Ширина</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Точка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>Як точка</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>Як мітка:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Прийняти</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Виберіть файл</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Дуга</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Багатокутник</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>У файлу %1 розширення не .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>Не існує файлу %1</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>List entities</source>
        <translation>Перелік елементів</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Накреслити лінію</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>Початок X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Початок Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>Кінець X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Кінець Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Прийняти</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Порожня початкова X-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Порожня початкова Y-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Порожня кінцева X-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Порожня кінцева Y-координата</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Зразок додатку</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="67"/>
        <source>File...</source>
        <translation type="unfinished">Файл…</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="77"/>
        <source>Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="81"/>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="85"/>
        <source>Cancel</source>
        <translation type="unfinished">Відміна</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="113"/>
        <source>Select file</source>
        <translation type="unfinished">Виберіть файл</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="121"/>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="134"/>
        <source>The file %1 not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="139"/>
        <source>Can&apos;t open the file %1</source>
        <translation type="unfinished">Неможливо відкрити файл %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="146"/>
        <source>%1 objects imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="168"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="181"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="260"/>
        <location filename="../picfile/picfile.cpp" line="269"/>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation type="unfinished">Відміна</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="177"/>
        <source>Layer:</source>
        <translation>Шар:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="210"/>
        <source>Style:</source>
        <translation>Стиль:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="211"/>
        <source>Height:</source>
        <translation>Висота:</translation>
    </message>
    <message>
        <source>Heigth:</source>
        <translation type="obsolete">Висота:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="212"/>
        <source>Separation</source>
        <translation>Поділ</translation>
    </message>
</context>
</TS>
